==> eiffelstudio-18.11.10.2592.tar: F_code/C6/se293.c <==
/*
 * Code for class SEQ_STRING
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "se293.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {SEQ_STRING}.search_string_after */
void F886_5929 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_INTEGER_32 arg2)
{
	GTCX
	RTEX;
	EIF_INTEGER_32 ti4_1;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLIU(2);
	
	RTEAA("search_string_after", 885, Current, 0, 2, 12110);
	RTGC;
	RTHOOK(1);
	if ((EIF_BOOLEAN) !F379_2857(Current)) {
		RTHOOK(2);
		ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_3_);
		ti4_1 = F883_5782(Current, arg1, ti4_1, arg2);
		*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_3_) = (EIF_INTEGER_32) ti4_1;
		RTHOOK(3);
		if ((EIF_BOOLEAN)(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_3_) == ((EIF_INTEGER_32) 0L))) {
			RTHOOK(4);
			*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_3_) = (EIF_INTEGER_32) (EIF_INTEGER_32) (*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_2_) + ((EIF_INTEGER_32) 1L));
		}
	}
	RTHOOK(5);
	RTLE;
	RTEE;
}

/* {SEQ_STRING}.current_item */
EIF_CHARACTER_8 F886_5931 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	
	
	RTEAA("current_item", 885, Current, 0, 0, 12112);
	RTHOOK(1);
	RTHOOK(2);
	RTEE;
	return (EIF_CHARACTER_8) F885_5840(Current, *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_3_));
}

/* {SEQ_STRING}.index */
EIF_INTEGER_32 F886_5932 (EIF_REFERENCE Current)
{
	return *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_3_);
}


/* {SEQ_STRING}.has */
EIF_BOOLEAN F886_5934 (EIF_REFERENCE Current, EIF_CHARACTER_8 arg1)
{
	GTCX
	RTEX;
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTEAA("has", 885, Current, 0, 1, 12115);
	RTGC;
	RTHOOK(1);
	if ((EIF_BOOLEAN) !F406_2866(Current)) {
		RTHOOK(2);
		ti4_1 = F883_5776(Current, arg1, ((EIF_INTEGER_32) 1L));
		Result = (EIF_BOOLEAN) (EIF_BOOLEAN)(ti4_1 != ((EIF_INTEGER_32) 0L));
	}
	RTHOOK(3);
	RTLE;
	RTEE;
	return Result;
}

/* {SEQ_STRING}.before */
EIF_BOOLEAN F886_5935 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	
	
	RTEAA("before", 885, Current, 0, 0, 12116);
	RTHOOK(1);
	RTHOOK(2);
	RTEE;
	return (EIF_BOOLEAN) (EIF_BOOLEAN) (*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_3_) < ((EIF_INTEGER_32) 1L));
}

/* {SEQ_STRING}.after */
EIF_BOOLEAN F886_5936 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	
	
	RTEAA("after", 885, Current, 0, 0, 12117);
	RTHOOK(1);
	RTHOOK(2);
	RTEE;
	return (EIF_BOOLEAN) (EIF_BOOLEAN) (*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_3_) > *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_2_));
}

/* {SEQ_STRING}.start */
void F886_5937 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	
	
	RTEAA("start", 885, Current, 0, 0, 12118);
	RTHOOK(1);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_3_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
	RTHOOK(2);
	RTEE;
}

/* {SEQ_STRING}.back */
void F886_5939 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	
	
	RTEAA("back", 885, Current, 0, 0, 12120);
	RTHOOK(1);
	(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_3_))--;
	RTHOOK(2);
	RTEE;
}

/* {SEQ_STRING}.forth */
void F886_5940 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	
	
	RTEAA("forth", 885, Current, 0, 0, 12121);
	RTHOOK(1);
	(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_3_))++;
	RTHOOK(2);
	RTEE;
}

void EIF_Minit293 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-19.05.10.3187.tar: F_code/C6/se293.c <==
/*
 * Code for class SEQ_STRING
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "se293.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {SEQ_STRING}.search_string_after */
void F886_5950 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_INTEGER_32 arg2)
{
	GTCX
	RTEX;
	EIF_INTEGER_32 ti4_1;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLIU(2);
	
	RTEAA("search_string_after", 885, Current, 0, 2, 12157);
	RTGC;
	RTHOOK(1);
	if ((EIF_BOOLEAN) !F379_2859(Current)) {
		RTHOOK(2);
		ti4_1 = F883_5803(Current, arg1, *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_3_), arg2);
		*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_3_) = (EIF_INTEGER_32) ti4_1;
		RTHOOK(3);
		if ((EIF_BOOLEAN)(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_3_) == ((EIF_INTEGER_32) 0L))) {
			RTHOOK(4);
			*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_3_) = (EIF_INTEGER_32) (EIF_INTEGER_32) (*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_2_) + ((EIF_INTEGER_32) 1L));
		}
	}
	RTHOOK(5);
	RTLE;
	RTEE;
}

/* {SEQ_STRING}.current_item */
EIF_CHARACTER_8 F886_5952 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	
	
	RTEAA("current_item", 885, Current, 0, 0, 12159);
	RTHOOK(1);
	RTHOOK(2);
	RTEE;
	return (EIF_CHARACTER_8) F885_5861(Current, *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_3_));
}

/* {SEQ_STRING}.index */
EIF_INTEGER_32 F886_5953 (EIF_REFERENCE Current)
{
	return *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_3_);
}


/* {SEQ_STRING}.has */
EIF_BOOLEAN F886_5955 (EIF_REFERENCE Current, EIF_CHARACTER_8 arg1)
{
	GTCX
	RTEX;
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTEAA("has", 885, Current, 0, 1, 12162);
	RTGC;
	RTHOOK(1);
	if ((EIF_BOOLEAN) !F406_2868(Current)) {
		RTHOOK(2);
		ti4_1 = F883_5797(Current, arg1, ((EIF_INTEGER_32) 1L));
		Result = (EIF_BOOLEAN) (EIF_BOOLEAN)(ti4_1 != ((EIF_INTEGER_32) 0L));
	}
	RTHOOK(3);
	RTLE;
	RTEE;
	return Result;
}

/* {SEQ_STRING}.before */
EIF_BOOLEAN F886_5956 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	
	
	RTEAA("before", 885, Current, 0, 0, 12163);
	RTHOOK(1);
	RTHOOK(2);
	RTEE;
	return (EIF_BOOLEAN) (EIF_BOOLEAN) (*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_3_) < ((EIF_INTEGER_32) 1L));
}

/* {SEQ_STRING}.after */
EIF_BOOLEAN F886_5957 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	
	
	RTEAA("after", 885, Current, 0, 0, 12164);
	RTHOOK(1);
	RTHOOK(2);
	RTEE;
	return (EIF_BOOLEAN) (EIF_BOOLEAN) (*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_3_) > *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_2_));
}

/* {SEQ_STRING}.start */
void F886_5958 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	
	
	RTEAA("start", 885, Current, 0, 0, 12165);
	RTHOOK(1);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_3_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
	RTHOOK(2);
	RTEE;
}

/* {SEQ_STRING}.forth */
void F886_5961 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	
	
	RTEAA("forth", 885, Current, 0, 0, 12168);
	RTHOOK(1);
	(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_3_))++;
	RTHOOK(2);
	RTEE;
}

void EIF_Minit293 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
